from dataclasses import dataclass, field

from dataclasses_json import dataclass_json, config


@dataclass_json
@dataclass
class LicenseRules:
    can_persist: bool = field(metadata=config(field_name="canPersist"), default=None)
    rental_duration: float = field(metadata=config(field_name="rentalDuration"), default=None)



from vdocipher.resources.request import authenticate
from vdocipher.resources.video import Video, UploadCredentials
from vdocipher.resources.otp import OTP
from vdocipher.resources.annotate import Annotate
from vdocipher.resources.license_rules import LicenseRules
